@@ -10,9 +10,28 @@
 // At your will you may redistribute the software under the terms of only one, two, or all three of the aforementioned licenses.
 
 #![forbid(unsafe_code)]
+#![warn(absolute_paths_not_starting_with_crate)]
+#![warn(elided_lifetimes_in_paths)]
+#![warn(explicit_outlives_requirements)]
+#![warn(meta_variable_misuse)]
+#![warn(missing_copy_implementations)]
+#![warn(missing_debug_implementations)]
 #![warn(missing_docs)]
+#![warn(non_ascii_idents)]
+#![warn(noop_method_call)]
+#![warn(single_use_lifetimes)]
+#![warn(trivial_casts)]
+#![warn(unreachable_pub)]
+#![warn(unused_crate_dependencies)]
+#![warn(unused_extern_crates)]
+#![warn(unused_lifetimes)]
+#![warn(unused_results)]
 
-//! Helper library for [NaTE](https://crates.io/crates/nate).
+//! [![GitHub Workflow Status](https://img.shields.io/github/workflow/status/Kijewski/nate/CI)](https://github.com/Kijewski/nate/actions/workflows/ci.yml)
+//! [![Crates.io](https://img.shields.io/crates/v/nate-derive)](https://crates.io/crates/nate-derive)
+//! [![License](https://img.shields.io/crates/l/nate-derive?color=informational)](/LICENSES)
+//!
+//! Proc-macros for [NaTE](https://crates.io/crates/nate).
 //!
 //! This libary implements the `#![derive(Nate)]` annotation.
 
@@ -230,7 +249,8 @@ fn load_file(path: &Path) -> Vec<u8> {
     let mut buf = Vec::new();
     match OpenOptions::new().read(true).open(&path) {
         Ok(mut f) => {
-            f.read_to_end(&mut buf)
+            let _ = f
+                .read_to_end(&mut buf)
                 .expect("Could not read source file even after successfully opening it.");
         }
         Err(err) => {
@@ -271,12 +291,22 @@ fn parse_file(path: &Path, mut output: impl Write) {
                 for (data_index, data) in blocks.iter().enumerate() {
                     match data {
                         Data(_) | Raw(_) => {}
-                        Escaped(_) | Debug(_) | Verbose(_) => {
+                        Escaped(_) => {
                             writeln!(
                                 output,
                                 "let _name_arg_{block}_{data} = \
-                                (&::nate::_escape::TagWrapper::new(_name_arg_{block}_{data})).\
-                                wrap(_name_arg_{block}_{data});",
+                                    (&::nate::_escape::TagWrapper::new(_name_arg_{block}_{data})).\
+                                    wrap(_name_arg_{block}_{data});",
+                                block = block_index,
+                                data = data_index,
+                            )
+                            .unwrap();
+                        }
+                        Debug(_) | Verbose(_) => {
+                            writeln!(
+                                output,
+                                "let _name_arg_{block}_{data} = \
+                                    ::nate::XmlEscape(_name_arg_{block}_{data});",
                                 block = block_index,
                                 data = data_index,
                             )
